@@ -154,11 +154,13 @@ class AbstractMatcher {
         A(false),
         N(false),
         W(false),
+        X(false),
         T(8)
     { }
     bool A; ///< accept any/all (?^X) negative patterns as Const::REDO accept index codes
     bool N; ///< nullable, find may return empty match (N/A to scan, split, matches)
-    bool W; ///< half-check for "whole words", check only left of \< and right of \> for non-word character
+    bool W; ///< reflex::Matcher matches whole words as if bound by \< and \>
+    bool X; ///< reflex::LineMatcher matches empty lines
     char T; ///< tab size, must be a power of 2, default is 8, for column count and indent \i, \j, and \k
   };
   /// AbstractMatcher::Iterator class for scanning, searching, and splitting input character sequences.
@@ -356,7 +358,8 @@ class AbstractMatcher {
     {
       opt_.A = false; // when true: accept any/all (?^X) negative patterns as Const::REDO accept index codes
       opt_.N = false; // when true: find may return empty match (N/A to scan, split, matches)
-      opt_.W = false; // when true: half-check for "whole words", check only left of \< and right of \> for non-word character
+      opt_.W = false; // when true: reflex::Matcher matches whole words as if bound by \< and \>
+      opt_.X = false; // when true: reflex::LineMatcher matches empty lines
       opt_.T = 8;     // tab size 1, 2, 4, or 8
       if (opt)
       {
@@ -373,6 +376,9 @@ class AbstractMatcher {
             case 'W':
               opt_.W = true;
               break;
+            case 'X':
+              opt_.X = true;
+              break;
             case 'T':
               opt_.T = isdigit(*(s += (s[1] == '=') + 1)) ? static_cast<char>(*s - '0') : 0;
               break;
@@ -661,7 +667,7 @@ class AbstractMatcher {
     lno_ = n;
   }
   /// Updates and returns the starting line number of the match in the input character sequence.
-  inline size_t lineno()
+  size_t lineno()
     /// @returns line number
   {
 #if WITH_SPAN
@@ -677,45 +683,8 @@ class AbstractMatcher {
       }
       else
       {
-#if defined(HAVE_AVX512BW) && (!defined(_MSC_VER) || defined(_WIN64))
-        if (have_HW_AVX512BW())
-          n = simd_nlcount_avx512bw(s, t);
-        else if (have_HW_AVX2())
-          n = simd_nlcount_avx2(s, t);
-        else
-          n = simd_nlcount_sse2(s, t);
-#elif defined(HAVE_AVX2)
-        if (have_HW_AVX2())
-          n = simd_nlcount_avx2(s, t);
-        else
-          n = simd_nlcount_sse2(s, t);
-#elif defined(HAVE_SSE2)
-        n = simd_nlcount_sse2(s, t);
-#elif defined(HAVE_NEON)
-        n = simd_nlcount_neon(s, t);
-#endif
-        // clang/gcc 4-way auto-vectorizable loop
-        uint32_t n0 = 0, n1 = 0, n2 = 0, n3 = 0;
-        while (s < t - 3)
-        {
-          n0 += s[0] == '\n';
-          n1 += s[1] == '\n';
-          n2 += s[2] == '\n';
-          n3 += s[3] == '\n';
-          s += 4;
-        }
-        n += n0 + n1 + n2 + n3;
-        // epilogue
-        if (s < t)
-        {
-          n += *s == '\n';
-          if (++s < t)
-          {
-            n += *s == '\n';
-            if (++s < t)
-              n += *s == '\n';
-          }
-        }
+        // count line numbers
+        n = nlcount(s, t);
       }
       // if newlines are detected, then find begin of the last line to adjust bol
       if (n > 0)
@@ -963,13 +932,13 @@ class AbstractMatcher {
     else if (got_ == '\n')
       got_ = Const::UNK;
   }
-  /// Returns true if this matcher matched text that begins a word.
+  /// Returns true if this matcher matched text that begins an ASCII word.
   inline bool at_bow()
     /// @returns true if this matcher matched text that begins a word
   {
     return !isword(got_) && isword(txt_ < buf_ + end_ ? static_cast<unsigned char>(*txt_) : peek_more());
   }
-  /// Returns true if this matcher matched text that ends a word.
+  /// Returns true if this matcher matched text that ends an ASCII word.
   inline bool at_eow()
     /// @returns true if this matcher matched text that ends a word
   {
@@ -1748,19 +1717,19 @@ class PatternMatcher : public AbstractMatcher {
     return *this;
   }
   /// Returns true if this matcher has a pattern.
-  bool has_pattern() const
+  inline bool has_pattern() const
     /// @returns true if this matcher has a pattern
   {
     return pat_ != NULL;
   }
   /// Returns true if this matcher has its own pattern not received from another matcher (responsible to delete).
-  bool own_pattern() const
+  inline bool own_pattern() const
     /// @returns true if this matcher has its own pattern
   {
     return own_ && pat_ != NULL;
   }
   /// Returns a reference to the pattern object associated with this matcher.
-  const Pattern& pattern() const
+  virtual const Pattern& pattern() const
     /// @returns reference to pattern object
   {
     ASSERT(pat_ != NULL);
@@ -1885,19 +1854,19 @@ class PatternMatcher<std::string> : public AbstractMatcher {
     return *this;
   }
   /// Returns true if this matcher has a pattern.
-  bool has_pattern() const
+  inline bool has_pattern() const
     /// @returns true if this matcher has a pattern
   {
     return pat_ != NULL;
   }
   /// Returns true if this matcher has its own pattern not received from another matcher (responsible to delete).
-  bool own_pattern() const
+  inline bool own_pattern() const
     /// @returns true if this matcher has its own pattern
   {
     return own_ && pat_ != NULL;
   }
   /// Returns a reference to the pattern string associated with this matcher.
-  const Pattern& pattern() const
+  virtual const Pattern& pattern() const
     /// @returns reference to pattern string
   {
     ASSERT(pat_ != NULL);
