@@ -199,9 +199,9 @@ extern const char *flag_view;
 extern std::string              flag_filter;
 extern std::string              flag_hyperlink_prefix; // internal flag
 extern std::string              flag_hyperlink_path; // internal flag
+extern std::string              flag_regexp; // internal flag
 extern std::set<std::string>    flag_config_files; // internal flag
 extern std::set<std::string>    flag_ignore_files;
-extern std::vector<std::string> flag_regexp;
 extern std::vector<std::string> flag_file;
 extern std::vector<std::string> flag_file_type;
 extern std::vector<std::string> flag_file_extension;
