@@ -344,11 +344,23 @@ void Screen::cleanup()
 // return character display width, 0 (non-spacing or invalid character), 1 (single width) or 2 (double width)
 int Screen::wchar_width(uint32_t wc)
 {
-  /* based on https://www.cl.cam.ac.uk/~mgk25/ucs/wcwidth.c with full table
+  // ignore invisible characters, such as invalid UTF-8
+  if (wc == 0)
+    return 0;
+
+  // control characters are double width to display them e.g. as \t or ^I
+  if (wc < 0x20 || wc == 0x7f)
+    return 2;
+
+  /* Based on https://www.cl.cam.ac.uk/~mgk25/ucs/wcwidth.c with full table
      generated by "uniset +cat=Me +cat=Mn +cat=Cf -00AD +1160-11FF +200B c"
      from https://www.unicode.org/Public/UCD/latest/ucd/EastAsianWidth.txt
      this is a compressed table of combining character ranges, stored as
-     range.first << 8 | (range.last - range.first) */
+     range.first << 8 | (range.last - range.first)
+
+     We don't use wcwidth() because it is broken on some systems, e.g. MacOS
+     wcwidth(0x1f600) returns -1 for the emoticon U+1F600
+  */
   static const uint32_t combining[] = {
     0x3006f, 0x48303, 0x48801, 0x5912c, 0x5bf00, 0x5c101, 0x5c401, 0x5c700,
     0x60003, 0x61005, 0x64b13, 0x67000, 0x6d60e, 0x6e701, 0x6ea03, 0x70f00,
@@ -375,14 +387,6 @@ int Screen::wchar_width(uint32_t wc)
   int min = 0;
   int max = sizeof(combining) / sizeof(uint32_t) - 1;
 
-  // ignore invisible characters, such as invalid UTF-8
-  if (wc == 0)
-    return 0;
-
-  // control characters are double width to display them e.g. as \t or ^I
-  if (wc < 0x20 || wc == 0x7f)
-    return 2;
-
   // binary search in table of non-spacing characters
   if (wc >= (combining[0] >> 8) && wc <= (combining[max] >> 8) + (combining[max] & 0xff))
   {
@@ -435,7 +439,7 @@ uint32_t Screen::wchar(const char *ptr, const char **endptr)
     return c1;
   }
 
-  if ((c1 & 0xc0) != 0xc0 || c1 <= 0xc1 || c1 > 0xf4)
+  if (c1 < 0xc2 || c1 > 0xf4)
   {
     if (endptr != NULL)
       *endptr = ptr;
