@@ -44,6 +44,7 @@
 #include <ctime>
 #include <climits>
 #include <exception>
+#include <stdexcept>
 #include <streambuf>
 #include <zlib.h>
 
@@ -1362,8 +1363,8 @@ class zstreambuf : public std::streambuf {
 
       catch (const std::invalid_argument&)
       {
-        /* non-seekable 7zip files cannot be decompressed,  */
-        cannot_decompress("non-seekable 7zip archive", pathname);
+        /* non-seekable and password-protected 7zip files cannot be decompressed */
+        cannot_decompress("7zip archive: encrypted data or 7z input is not seekable", pathname);
         file_ = NULL;
       }
 
@@ -1579,7 +1580,9 @@ class zstreambuf : public std::streambuf {
     if (num > len)
       num = len;
 
-    memcpy(buf, buf_ + cur_, num);
+    // move decompressed data to destination buf, which can be the same as the source buffer after get_buffer()
+    if (buf != buf_ + cur_)
+      memmove(buf, buf_ + cur_, num);
 
     cur_ += num;
 
